FlutterMultiselectLayoutDelegate class

Inheritance

Constructors

FlutterMultiselectLayoutDelegate({required int length, required double minTextFieldWidth, required double spacing, required Offset position})

Properties

hashCode → int
The hash code for this object.
no setterinherited
length → int
final
minTextFieldWidth → double
final
parentSize ↔ Size
This is used for
getter/setter pair
position → Offset
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spacing → double
final

Methods

getSize(BoxConstraints constraints) → Size
Override this method to return the size of this object given the incoming constraints.
override
hasChild(Object childId) → bool
True if a non-null LayoutChild was provided for the specified id.
inherited
layoutChild(Object childId, BoxConstraints constraints) → Size
Ask the child to update its layout within the limits specified by the constraints parameter. The child's size is returned.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
performLayout(Size size) → void
Override this method to lay out and position all children given this widget's size.
override
positionChild(Object childId, Offset offset) → void
Specify the child's origin relative to this origin.
inherited
shouldRelayout(covariant FlutterMultiselectLayoutDelegate oldDelegate) → bool
Override this method to return true when the children need to be laid out.
override
toString() → String
Override this method to include additional information in the debugging data printed by debugDumpRenderTree and friends.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getTagId(int id) → String

Constants

leadingPaddingId → const String
tagId → const String
textFieldId → const String
textId → const String